summaryrefslogtreecommitdiffstats
path: root/kdnssd/ioslave/dnssd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdnssd/ioslave/dnssd.cpp')
-rw-r--r--kdnssd/ioslave/dnssd.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdnssd/ioslave/dnssd.cpp b/kdnssd/ioslave/dnssd.cpp
index 0f16008e..e94b7303 100644
--- a/kdnssd/ioslave/dnssd.cpp
+++ b/kdnssd/ioslave/dnssd.cpp
@@ -351,12 +351,12 @@ extern "C"
{
int KDE_EXPORT kdemain( int argc, char **argv )
{
// KApplication is necessary to use other ioslaves
putenv(strdup("SESSION_MANAGER="));
TDECmdLineArgs::init(argc, argv, "kio_zeroconf", 0, 0, 0, 0);
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication::disableAutoDcopRegistration();
- KApplication app;
+ TDEApplication::disableAutoDcopRegistration();
+ TDEApplication app;
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
ZeroConfProtocol slave( args->arg(0), args->arg(1), args->arg(2) );
slave.dispatchLoop();
@@ -351,12 +351,12 @@ extern "C"
int KDE_EXPORT kdemain( int argc, char **argv )
{
- // KApplication is necessary to use other ioslaves
+ // TDEApplication is necessary to use other ioslaves
putenv(strdup("SESSION_MANAGER="));
TDECmdLineArgs::init(argc, argv, "kio_zeroconf", 0, 0, 0, 0);